@@ -10,7 +10,11 @@ if [ ! -f $profile_file ]; then
 
   echo "export PYTHONPATH=${package_root}/lib:\$PYTHONPATH" >> $profile_file
   echo "export ROOT_DYN_PATH=${package_root}/lib:\$ROOT_DYN_PATH" >> $profile_file
-  echo "export ROOT_INCLUDE_PATH=${package_root}/include:${package_root}/include/GPU:\$ROOT_INCLUDE_PATH" >> $profile_file
+  echo "export ROOT_INCLUDE_PATH=${package_root}/include:\$ROOT_INCLUDE_PATH" >> $profile_file
+  echo "export ROOT_INCLUDE_PATH=${package_root}/include/GPU:\$ROOT_INCLUDE_PATH" >> $profile_file
+  echo "export ROOT_INCLUDE_PATH=${package_root}/include/fairmq:\$ROOT_INCLUDE_PATH" >> $profile_file
+  echo "export ROOT_INCLUDE_PATH=${package_root}/include/QualityControl:\$ROOT_INCLUDE_PATH" >> $profile_file
+  echo "export ROOT_INCLUDE_PATH=${package_root}/include/vmc:\$ROOT_INCLUDE_PATH" >> $profile_file
   echo "export PATH=${package_root}/bin:\$PATH" >> $profile_file
   chmod a+x $profile_file
 fi;
@@ -32,6 +36,6 @@ if [[ "$package" == *"$devel_suffix"* ]]; then
   if [ ! -f $devel_file ]; then
     echo "export LIBRARY_PATH=/opt/o2/lib/" >> $devel_file
     echo "export CPLUS_INCLUDE_PATH=/opt/o2/include/" >> $devel_file
-    echo "source /opt/rh/gcc-toolset-10/enable" >> $devel_file
+    echo "source /opt/rh/gcc-toolset-12/enable" >> $devel_file
   fi
 fi
